← Back to team overview

dolfin team mailing list archive

Re: [Branch ~dolfin-core/dolfin/main] Rev 5095: Make FindPETSc and FindSLEPc report not found if test program fails. Also use PETSC_DIR in FindSL...

 



On 29/08/10 08:57, Johannes Ring wrote:
On Sun, Aug 29, 2010 at 9:55 AM,<noreply@xxxxxxxxxxxxx>  wrote:
------------------------------------------------------------
revno: 5095
committer: Johannes Ring<johannr@xxxxxxxxx>
branch nick: dolfin
timestamp: Sun 2010-08-29 09:53:19 +0200
message:
  Make FindPETSc and FindSLEPc report not found if test program fails.

The test program in FindSLEPc fails for SLEPc 3.0.0:

http://fenics.org:8080/builders/dolfin-jaunty-amd64/builds/847/steps/dolfin%20build/logs/CMakeError.log


Should be fixed now.

Garth

Johannes

Also use PETSC_DIR in FindSLEPc.
modified:
  cmake/modules/FindPETSc.cmake
  cmake/modules/FindSLEPc.cmake


--
lp:dolfin
https://code.launchpad.net/~dolfin-core/dolfin/main

Your team DOLFIN Core Team is subscribed to branch lp:dolfin.
To unsubscribe from this branch go to https://code.launchpad.net/~dolfin-core/dolfin/main/+edit-subscription

=== modified file 'cmake/modules/FindPETSc.cmake'
--- cmake/modules/FindPETSc.cmake       2010-08-24 20:40:57 +0000
+++ cmake/modules/FindPETSc.cmake       2010-08-29 07:53:19 +0000
@@ -156,4 +156,4 @@
  include(FindPackageHandleStandardArgs)
  find_package_handle_standard_args(PETSc
   "PETSc could not be found. Be sure to set PETSC_DIR and PETSC_ARCH."
-  PETSC_DIR PETSC_INCLUDE_DIRS PETSC_LIBRARIES)
+  PETSC_DIR PETSC_INCLUDE_DIRS PETSC_LIBRARIES PETSC_TEST_RUNS)

=== modified file 'cmake/modules/FindSLEPc.cmake'
--- cmake/modules/FindSLEPc.cmake       2010-08-24 20:40:57 +0000
+++ cmake/modules/FindSLEPc.cmake       2010-08-29 07:53:19 +0000
@@ -6,7 +6,8 @@
  #  SLEPC_LIBARIES     - libraries for SLEPc
  #  SLEPC_DIR          - directory where SLEPc is built
  #
 # Assumes that PETSC_ARCH has been set by alredy calling find_package(PETSc)

  # Set debian_arches (PETSC_ARCH for Debian-style installations)
  foreach (debian_arches linux kfreebsd)
@@ -53,6 +54,7 @@
  "# This file was autogenerated by FindSLEPc.cmake
  SLEPC_DIR  = ${SLEPC_DIR}
  PETSC_ARCH = ${PETSC_ARCH}
+PETSC_DIR = ${PETSC_DIR}
  include ${SLEPC_DIR}/conf/slepc_common
  show :
        -@echo -n \${\${VARIABLE}}
@@ -112,5 +114,5 @@
  # Standard package handling
  include(FindPackageHandleStandardArgs)
  find_package_handle_standard_args(SLEPc
-  "SLEPc could not be found. Be sure to set SLEPC_DIR and PETSC_ARCH."
-  SLEPC_DIR SLEPC_INCLUDE_DIRS SLEPC_LIBRARIES)
+  "SLEPc could not be found. Be sure to set SLEPC_DIR, PETSC_DIR, and PETSC_ARCH."
+  SLEPC_DIR SLEPC_INCLUDE_DIRS SLEPC_LIBRARIES SLEPC_TEST_RUNS)
@@ -6,7 +6,8 @@
  #  SLEPC_DIR          - directory where SLEPc is built
  #
-# Assumes that PETSC_ARCH has been set by alredy calling find_package(PETSc)
+# Assumes that PETSC_DIR and PETSC_ARCH has been set by
+# alredy calling find_package(PETSc)

  # Set debian_arches (PETSC_ARCH for Debian-style installations)




_______________________________________________
Mailing list: https://launchpad.net/~dolfin
Post to     : dolfin@xxxxxxxxxxxxxxxxxxx
Unsubscribe : https://launchpad.net/~dolfin
More help   : https://help.launchpad.net/ListHelp



References